==> foundry_platform_sdk-0.65.0.tar.gz: foundry_platform_sdk-0.65.0/foundry/v1/ontologies/errors/_interface_type_not_found.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v1.ontologies.models._interface_type_api_name import InterfaceTypeApiName
from foundry.v1.ontologies.models._interface_type_rid import InterfaceTypeRid


class InterfaceTypeNotFoundParameters(TypedDict):
    """The requested interface type is not found, or the client token does not have access to it."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    apiName: NotRequired[InterfaceTypeApiName]

    rid: NotRequired[InterfaceTypeRid]


@dataclass
class InterfaceTypeNotFound(PalantirRPCException):
    name: Literal["InterfaceTypeNotFound"]
    parameters: InterfaceTypeNotFoundParameters
    error_instance_id: str


__all__ = ["InterfaceTypeNotFound"]

==> foundry_platform_sdk-0.90.0.tar.gz: foundry_platform_sdk-0.90.0/foundry/v1/ontologies/errors/_interface_type_not_found.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import NotFoundError
from foundry.v1.ontologies.models._interface_type_api_name import InterfaceTypeApiName
from foundry.v1.ontologies.models._interface_type_rid import InterfaceTypeRid


class InterfaceTypeNotFoundParameters(TypedDict):
    """The requested interface type is not found, or the client token does not have access to it."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    apiName: NotRequired[InterfaceTypeApiName]

    rid: NotRequired[InterfaceTypeRid]


@dataclass
class InterfaceTypeNotFound(NotFoundError):
    name: Literal["InterfaceTypeNotFound"]
    parameters: InterfaceTypeNotFoundParameters
    error_instance_id: str


__all__ = ["InterfaceTypeNotFound"]
